"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const moment_timezone_1 = __importDefault(require("moment-timezone"));
const DateInputNoPicker_1 = require("./DateInputNoPicker");
test('formatDateInputNoPickerValue', () => {
    const m = moment_timezone_1.default.parseZone('2021-09-20T03:37:00.441Z');
    expect((0, DateInputNoPicker_1.formatDateInputNoPickerValue)(m, {
        includesTime: false,
        timeZone: 'America/Chicago',
    })).toBe('9/20/2021');
    expect((0, DateInputNoPicker_1.formatDateInputNoPickerValue)(m, {
        includesTime: true,
        timeZone: 'America/Chicago',
    })).toBe('9/19/2021 10:37 pm');
});
test('parseDateInputNoPickerValue', () => {
    var _a, _b, _c;
    expect((_a = (0, DateInputNoPicker_1.parseDateInputNoPickerValue)('9/20/2021', {
        includesTime: false,
        timeZone: 'America/Chicago',
    })) === null || _a === void 0 ? void 0 : _a.toISOString()).toBe('2021-09-20T00:00:00.000Z');
    expect((_b = (0, DateInputNoPicker_1.parseDateInputNoPickerValue)('9/20/2021', {
        includesTime: false,
        timeZone: 'Europe/Athens',
    })) === null || _b === void 0 ? void 0 : _b.toISOString()).toBe('2021-09-20T00:00:00.000Z');
    expect((_c = (0, DateInputNoPicker_1.parseDateInputNoPickerValue)('9/20/2021 3:37 pm', {
        includesTime: true,
        timeZone: 'America/Chicago',
    })) === null || _c === void 0 ? void 0 : _c.toISOString()).toBe('2021-09-20T20:37:00.000Z');
});
describe('round trip', () => {
    test('includesTime=false', () => {
        var _a;
        const m = moment_timezone_1.default.parseZone('2021-09-20T03:37:00.441Z');
        const formatted = (0, DateInputNoPicker_1.formatDateInputNoPickerValue)(m, {
            includesTime: false,
            timeZone: 'America/Chicago',
        });
        expect((_a = (0, DateInputNoPicker_1.parseDateInputNoPickerValue)(formatted, {
            includesTime: false,
            timeZone: 'Europe/Athens',
        })) === null || _a === void 0 ? void 0 : _a.toISOString()).toBe('2021-09-20T00:00:00.000Z');
    });
    test('includesTime=true', () => {
        var _a;
        const m = moment_timezone_1.default.parseZone('2021-09-20T03:37:00.441Z');
        const formatted = (0, DateInputNoPicker_1.formatDateInputNoPickerValue)(m, {
            includesTime: true,
            timeZone: 'America/Chicago',
        });
        expect((_a = (0, DateInputNoPicker_1.parseDateInputNoPickerValue)(formatted, {
            includesTime: true,
            timeZone: 'America/Chicago',
        })) === null || _a === void 0 ? void 0 : _a.toISOString()).toBe('2021-09-20T03:37:00.000Z');
    });
});
